%%Bayesian estimation 
%priors are taken from Smets&Wouters (2007)


var y infl r epsD epsS epsA epsM;
var y_obs infl_obs r_obs; 


varexo epsDS epsSS epsAS epsMS;

parameters sigma betta eta theta phipi rhoD rhoS rhoA rhoM;


sigma = 1;
betta = 0.99;
eta = 2.0;
theta = 0.5;
phipi = 1.5;
rhoD = 0.75; 
rhoS = 0.75;
rhoA = 0.95;
rhoM = 0.5;



model(linear);


[name='IScurve']
y = y(+1)-(1/sigma)*(r-infl(+1)+epsD);


[name='Phillips Curve']
infl = betta*infl(+1)+((1-betta*theta)*(1-theta)/theta)*((sigma+eta)*(y-((1-eta)/(sigma+eta))*epsA))+epsS;

[name='Monetary policy rule']
r = phipi*infl+epsM;




[name='Demand shock']
epsD = rhoD*epsD(-1)+epsDS;

[name='Supply shock']
epsS = rhoS*epsS(-1)+epsSS;

[name='Technology shock']
epsA = rhoA*epsA(-1)+epsAS;

[name='Monetary policy shock']
epsM = rhoM*epsM(-1)+epsMS;

[name='measurement equations']
y_obs=y;
infl_obs =infl;
r_obs=r;
end;


steady;
check;

stoch_simul(hp_filter=1600);



estimated_params;

%parameter_name      initial_value    LB        UB       prior_shape            prior_mean      prior_stderr


%parameters utility function
sigma,                  ,               ,       ,           normal_pdf,         1.5,            0.375;
betta,                  ,               ,       ,           gamma_pdf,          1,              0.1;
eta,                    ,               ,       ,           normal_pdf,         2,              0.75;
theta,                  ,               ,       ,           beta_pdf,           0.5,            0.1;

%parameters monetary policy rule
phipi,                  ,               ,       ,           normal_pdf,         1.5,            0.125;

%exogenous processes-stderr
stderr epsDS,           ,               ,       ,           inv_gamma_pdf,      0.1,            2;                         
stderr epsSS,           ,               ,       ,           inv_gamma_pdf,      0.1,            2;                    
stderr epsAS,           ,               ,       ,           inv_gamma_pdf,      0.1,            2;           
stderr epsMS,           ,               ,       ,           inv_gamma_pdf,      0.1,            2;             

%exogenous processes-autocorrelation 
rhoD,                   ,               ,       ,           beta_pdf,           0.5,            0.2;
rhoS,                   ,               ,       ,           beta_pdf,           0.5,            0.2; 
rhoA,                   ,               ,       ,           beta_pdf,           0.5,            0.2;
rhoM,                   ,               ,       ,           beta_pdf,           0.5,            0.2;


end;

varobs y_obs infl_obs r_obs;

estimation (datafile='mydatafile.xlsx',xls_sheet=sheet1, first_obs=1, mode_compute=4,mh_jscale=0.5,mh_replic=20000, mh_drop=0.3,mh_nblocks=2,bayesian_irf,irf=30) y_obs infl_obs r_obs;

